@@ -21,14 +21,14 @@ const families = [
     unicodes: [],
   },
   {
-    type: 'Devanagari',
-    name: 'IBM Plex Devanagari',
+    type: 'Sans Devanagari',
+    name: 'IBM Plex Sans Devanagari',
     hasItalic: false,
     unicodes: [],
   },
   {
-    type: 'Thai',
-    name: 'IBM Plex Thai',
+    type: 'Sans Thai',
+    name: 'IBM Plex Sans Thai',
     hasItalic: false,
     unicodes: [],
   },
@@ -44,8 +44,8 @@ const families = [
     unicodes: ['Latin1', 'Latin2', 'Latin3', 'Pi', 'Cyrillic'],
   },
   {
-    type: 'Arabic',
-    name: 'IBM Plex Arabic',
+    type: 'Sans Arabic',
+    name: 'IBM Plex Sans Arabic',
     hasItalic: false,
     unicodes: [],
   },
